@@ -3,9 +3,9 @@ Term::Choose::Win32;
 
 use warnings;
 use strict;
-use 5.008000;
+use 5.008003;
 
-our $VERSION = '1.116_03';
+our $VERSION = '1.200_01';
 
 use Win32::Console qw( STD_INPUT_HANDLE ENABLE_MOUSE_INPUT ENABLE_PROCESSED_INPUT STD_OUTPUT_HANDLE
                        RIGHT_ALT_PRESSED LEFT_ALT_PRESSED RIGHT_CTRL_PRESSED LEFT_CTRL_PRESSED SHIFT_PRESSED
@@ -150,7 +150,7 @@ sub __set_cursor_position {
 
 sub __clear_screen {
     my ( $self ) = @_;
-    $self->{output}->cls( $self->{def_attr} );
+    $self->{output}->Cls( $self->{def_attr} );
 }
 
 
